@@ -3,6 +3,7 @@ extconf.rb for Ruby/Atk extention library
 =end
 
 PACKAGE_NAME = "atk"
+PACKAGE_ID   = "atk"
 
 TOPDIR = File.expand_path(File.dirname(__FILE__) + '/..') 
 SRCDIR = TOPDIR + '/atk/src'
@@ -12,7 +13,7 @@ $LOAD_PATH.unshift MKMF_GNOME2_DIR
 
 require 'mkmf-gnome2'
 
-PKGConfig.have_package('atk') or exit 1
+PKGConfig.have_package(PACKAGE_ID) or exit 1
 setup_win32(PACKAGE_NAME)
 
 have_func('atk_action_get_localized_name')
@@ -25,13 +26,18 @@ have_func('atk_hyperlink_is_selected_link')
 have_func('atk_text_get_bounded_ranges')
 have_func('atk_role_get_localized_name')
 have_func('atk_text_clip_type_get_type')
-have_func('atk_text_free_ranges')
+
+unless /cygwin/ =~ RUBY_PLATFORM
+  #FIXME
+  have_func('atk_text_free_ranges')
+end
 
 add_depend_package("glib2", "glib/src", TOPDIR)
 add_distcleanfile("rbatkinits.c")
 
+make_version_header("ATK", PACKAGE_ID)
+
 create_makefile_at_srcdir(PACKAGE_NAME, SRCDIR, "-DRUBY_ATK_COMPILATION") {
-  File.delete("rbatkinits.c") if FileTest.exist?("rbatkinits.c")
   system("ruby #{SRCDIR}/makeinits.rb #{SRCDIR}/*.c > rbatkinits.c") or raise "failed to make ATK inits"
 }
 
