@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   loader.rb - Ruby/GdkPixbuf sample script.
 
   Copyright (c) 2003 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: loader.rb,v 1.1 2003/01/17 19:20:44 mutoh Exp $
+  $Id: loader.rb,v 1.2 2005/03/22 17:41:25 silicio Exp $
 =end
 require 'gtk2'
 
