@@ -86,17 +86,22 @@ def check_win32()
 end
 
 def set_output_lib(target_name)
-  filename = "libruby-#{target_name}.a"
   if /cygwin|mingw/ =~ RUBY_PLATFORM
+    filename = "libruby-#{target_name}.a"
     if RUBY_VERSION > "1.8.0"
       $DLDFLAGS << ",--out-implib=#{filename}" if filename
     elsif RUBY_VERSION > "1.8"
-      CONFIG["DLDFLAGS"].gsub!(/ -Wl,--out-implib=[^ ]+/, '')
-      CONFIG["DLDFLAGS"] << " -Wl,--out-implib=#{filename}" if filename
+      $DLDFLAGS.gsub!(/ -Wl,--out-implib=[^ ]+/, '')
+      $DLDFLAGS << " -Wl,--out-implib=#{filename}" if filename
     else
-      CONFIG["DLDFLAGS"].gsub!(/ --output-lib\s+[^ ]+/, '')
-      CONFIG["DLDFLAGS"] << " --output-lib #{filename}" if filename
+      $DLDFLAGS.gsub!(/ --output-lib\s+[^ ]+/, '')
+      $DLDFLAGS << " --output-lib #{filename}" if filename
     end
+  elsif /mswin32/ =~ RUBY_PLATFORM
+      filename = "libruby-#{target_name}.lib"
+      $DLDFLAGS.gsub!(/ --output-lib\s+[^ ]+/, '')
+      $DLDFLAGS.gsub!(/ \/IMPLIB:[^ ]+/, '')
+      $DLDFLAGS << " /IMPLIB:#{filename}" if filename   
   end
 end
 
@@ -114,7 +119,7 @@ def add_depend_package(target_name, target_srcdir, topdir)
     $LDFLAGS << " -L#{topdir}/#{target_srcdir}"
   elsif /mswin32/ =~ RUBY_PLATFORM
     $DLDFLAGS << " /libpath:#{topdir}/#{target_srcdir}"
-    $libs << " #{target_name}.lib"
+    $libs << " libruby-#{target_name}.lib"
   end
 end
 
@@ -175,6 +180,45 @@ END
   mfile.close
 end
 
+# This is used for the library which doesn't support version info.
+def make_version_header(app_name, pkgname, dir = "src")
+  version = PKGConfig.modversion(pkgname).split(/\./)
+
+  filename = "rb#{app_name.downcase}version.h"
+
+  puts "creating #{filename}"
+
+  add_distcleanfile(filename)
+
+  out = File.open(File.join(dir, filename), "w")
+
+  out.print %Q[/* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
+/************************************************
+
+  #{filename} -
+
+  This file was generated by mkmf-gnome2.rb.
+
+************************************************/
+
+#ifndef __RB#{app_name}_VERSION_H__
+#define __RB#{app_name}_VERSION_H__
+
+#define #{app_name}_MAJOR_VERSION (#{version[0]})
+#define #{app_name}_MINOR_VERSION (#{version[1]})
+#define #{app_name}_MICRO_VERSION (#{version[2]})
+
+#define #{app_name}_CHECK_VERSION(major,minor,micro)    \\
+    (#{app_name}_MAJOR_VERSION > (major) || \\
+     (#{app_name}_MAJOR_VERSION == (major) && #{app_name}_MINOR_VERSION > (minor)) || \\
+     (#{app_name}_MAJOR_VERSION == (major) && #{app_name}_MINOR_VERSION == (minor) && \\
+      #{app_name}_MICRO_VERSION >= (micro)))
+
+
+#endif /* __RB#{app_name}_VERSION_H__ */
+]
+      out.close
+end
 
 def check_ruby_func
   $CPPFLAGS << " -I$(sitearchdir) "
