@@ -4,7 +4,7 @@
   rbgobj_signal.c -
 
   $Author: mutoh $
-  $Date: 2004/03/05 15:52:27 $
+  $Date: 2005/09/15 06:25:30 $
   created at: Sat Jul 27 16:56:01 JST 2002
 
   Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
@@ -243,6 +243,7 @@ gobj_sig_connect(argc, argv, self)
     const char* sig_name;
     guint signal_id;
     GQuark detail;
+    VALUE func;
 
     rb_scan_args(argc, argv, "1*", &sig, &rest);
 
@@ -256,7 +257,9 @@ gobj_sig_connect(argc, argv, self)
     if (!g_signal_parse_name(sig_name, CLASS2GTYPE(CLASS_OF(self)), &signal_id, &detail, TRUE))
         rb_raise(eNoSignalError, "no such signal: %s", sig_name);
 
-    rclosure = g_rclosure_new(G_BLOCK_PROC(), rest, 
+    func = G_BLOCK_PROC();
+    G_RELATIVE(self, func);
+    rclosure = g_rclosure_new(func, rest, 
                               rbgobj_get_signal_func(signal_id));
     i = g_signal_connect_closure_by_id(RVAL2GOBJ(self), signal_id, detail, rclosure, FALSE);
 
