@@ -3,8 +3,8 @@
 
   rbgobj_type.c -
 
-  $Author: kzys $
-  $Date: 2005/02/25 15:19:19 $
+  $Author: mutoh $
+  $Date: 2005/10/15 04:31:38 $
   created at: Sun Jun  9 20:31:47 JST 2002
  
   Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
@@ -748,15 +748,98 @@ interface_s_append_features(self, klass)
     return rb_call_super(1, &klass);
 }
 
+#if GLIB_CHECK_VERSION(2,4,0)
+static VALUE
+interface_install_property(self, pspec_obj)
+    VALUE self, pspec_obj;
+{
+    const RGObjClassInfo* cinfo = rbgobj_lookup_class(self);
+    gpointer ginterface;
+    GParamSpec* pspec;
+
+    if (cinfo->klass != self)
+        rb_raise(rb_eTypeError, "%s isn't registered class",
+                 rb_class2name(self));
+
+    pspec = G_PARAM_SPEC(RVAL2GOBJ(pspec_obj));
+
+    ginterface = g_type_default_interface_ref(cinfo->gtype);
+    g_object_interface_install_property(ginterface, pspec);
+    g_type_default_interface_unref(ginterface);
+
+    /* FIXME: define accessor methods */
+    return Qnil;
+}
+
+static VALUE
+interface_property(self, property_name)
+     VALUE self, property_name;
+{
+    gpointer ginterface;
+    const char* name;
+    GParamSpec* prop;
+    VALUE result;
+
+    if (SYMBOL_P(property_name)) {
+        name = rb_id2name(SYM2ID(property_name));
+    } else {
+        StringValue(property_name);
+        name = StringValuePtr(property_name);
+    }
+
+    ginterface = g_type_default_interface_ref(CLASS2GTYPE(self));
+
+    prop = g_object_interface_find_property(ginterface, name);
+    if (!prop){
+        g_type_default_interface_unref(ginterface);
+        rb_raise(rb_const_get(mGLib, rb_intern("NoPropertyError")), 
+                 "no such property: %s", name);
+    }
+
+    result = GOBJ2RVAL(prop);
+    g_type_default_interface_unref(ginterface);
+    return result;
+}
+
+static VALUE
+interface_properties(int argc, VALUE* argv, VALUE self)
+{
+    guint n_properties;
+    GParamSpec** props;
+    VALUE inherited_too;
+    VALUE ary;
+    int i;
+    gpointer ginterface;
+
+    GType gtype  = CLASS2GTYPE(self);
+    ary = rb_ary_new();
+    if (gtype != G_TYPE_INTERFACE){
+        ginterface = g_type_default_interface_ref(gtype);
+
+        if (rb_scan_args(argc, argv, "01", &inherited_too) == 0)
+            inherited_too = Qtrue;
+        
+        props = g_object_interface_list_properties(ginterface, &n_properties);
+        
+        for (i = 0; i < n_properties; i++){
+            if (RTEST(inherited_too)
+                || GTYPE2CLASS(props[i]->owner_type) == self)
+                rb_ary_push(ary, rb_str_new2(props[i]->name));
+        }
+        g_free(props);
+        g_type_default_interface_unref(ginterface);
+    }
+    return ary;
+}
+#endif
+
 static void
 rbgobj_init_interface(interf)
     VALUE interf;
 {
-    rb_extend_object(interf, mMetaInterface);
-    rb_define_singleton_method(interf, "append_features",
-                               interface_s_append_features, 1);
     /* pseudo inheritance */
     if (CLASS2GTYPE(interf) != G_TYPE_INTERFACE){
+        rb_extend_object(interf, GTYPE2CLASS(G_TYPE_INTERFACE));
         rb_include_module(interf, GTYPE2CLASS(G_TYPE_INTERFACE));
         rbgobj_define_property_accessors(interf);
     }
@@ -765,7 +848,17 @@ rbgobj_init_interface(interf)
 static void
 Init_interface()
 {
-    G_DEF_INTERFACE(G_TYPE_INTERFACE, "Interface", mGLib);
+    VALUE iface = G_DEF_INTERFACE(G_TYPE_INTERFACE, "Interface", mGLib);
+
+    rb_define_method(mMetaInterface, "append_features", interface_s_append_features, 1);
+#if GLIB_CHECK_VERSION(2,4,0)
+    rb_define_method(mMetaInterface, "install_property", interface_install_property, 1);
+    rb_define_method(mMetaInterface, "property", interface_property, 1);
+    rb_define_method(mMetaInterface, "properties", interface_properties, -1);
+#endif
+
+    rb_extend_object(iface, mMetaInterface);
+    rb_include_module(iface, mMetaInterface);
 }
 
 /**********************************************************************/
