@@ -4,9 +4,9 @@
   rbgobject.c -
 
   $Author: mutoh $
-  $Date: 2005/01/29 11:41:17 $
+  $Date: 2005/11/06 06:41:14 $
 
-  Copyright (C) 2003,2004  Ruby-GNOME2 Project Team
+  Copyright (C) 2003-2005  Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003  Masahiro Sakai
 
   This file is derived from rbgtkobject.c in Ruby/Gtk distribution.
@@ -27,6 +27,8 @@ static ID id_relatives;
 static ID id_delete;
 static ID id_module_eval;
 
+ID rbgobj_id_children;
+
 /**********************************************************************/
 
 void
@@ -65,8 +67,8 @@ rbgobj_instance_from_ruby_object(VALUE obj)
     case G_TYPE_PARAM:
         return rbgobj_param_spec_get_struct(obj);
     default:
-        rb_raise(rb_eTypeError, "fundamental type %s isn't supported",
-                 g_type_name(t));
+      rb_raise(rb_eTypeError, "%s isn't supported",
+               rb_class2name(CLASS_OF(obj)));
     }
 }
 
@@ -85,8 +87,8 @@ rbgobj_ruby_object_from_instance(gpointer instance)
     case G_TYPE_PARAM:
         return rbgobj_get_value_from_param_spec(instance);
     default:
-        rb_raise(rb_eTypeError, "fundamental type %s isn't supported",
-                 g_type_name(t));
+      rb_raise(rb_eTypeError, "%s isn't supported",
+               rb_class2name(CLASS_OF(instance)));
     }
 }
 
@@ -100,10 +102,13 @@ rbgobj_weak_notify(data, where_the_object_was)
     GObject* where_the_object_was;
 {
     gobj_holder* holder = data;
+
     if (holder->cinfo && holder->cinfo->free)
         holder->cinfo->free(holder->gobj); 
     if (RTEST(rb_ivar_defined(holder->self, id_relatives)))
         rb_ivar_set(holder->self, id_relatives, Qnil);
+    if (RTEST(rb_ivar_defined(holder->self, rbgobj_id_children)))
+        rb_ivar_set(holder->self, rbgobj_id_children, Qnil);
     /*
       XXX. We can't unref() here.
       Because ref_counted have been set to zero in g_object_real_dispose().
@@ -174,7 +179,6 @@ rbgobj_gobject_initialize(obj, cobj)
 
     g_object_set_qdata((GObject*)cobj, RUBY_GOBJECT_OBJ_KEY, (gpointer)holder);
     g_object_weak_ref((GObject*)cobj, (GWeakNotify)rbgobj_weak_notify, holder);
-
     {
         GType t1 = G_TYPE_FROM_INSTANCE(cobj);
         GType t2 = CLASS2GTYPE(CLASS_OF(obj));
@@ -234,16 +238,16 @@ void
 rbgobj_add_relative(obj, relative)
     VALUE obj, relative;
 {
-    VALUE ary = Qnil;
+    VALUE hash = Qnil;
 
     if (RTEST(rb_ivar_defined(obj, id_relatives)))
-        ary = rb_ivar_get(obj, id_relatives);
+        hash = rb_ivar_get(obj, id_relatives);
 
-    if (NIL_P(ary) || TYPE(ary) != T_ARRAY) {
-        ary = rb_ary_new();
-        rb_ivar_set(obj, id_relatives, ary);
+    if (NIL_P(hash) || TYPE(hash) != T_HASH) {
+        hash = rb_hash_new();
+        rb_ivar_set(obj, id_relatives, hash);
     }
-    rb_ary_push(ary, relative);
+    rb_hash_aset(hash, relative, Qnil);
 }
 
 void
@@ -280,8 +284,18 @@ rbgobj_remove_relative(obj, obj_ivar_id, hash_key)
     }
 }
 
+void
+rbgobj_remove_relative_all(obj, obj_ivar_id)
+    VALUE obj;
+    ID    obj_ivar_id;
+{
+    rb_ivar_set(obj, obj_ivar_id, Qnil);
+}
+
 static GHashTable* prop_exclude_list;
 
+#define IS_FLAG(bitmask, flag) (((bitmask) & (flag)) == (flag))
+
 void
 rbgobj_define_property_accessors(klass)
     VALUE klass;
@@ -338,7 +352,7 @@ rbgobj_define_property_accessors(klass)
                 pspec->name);
         }
 
-        if (pspec->flags & G_PARAM_WRITABLE){
+        if (IS_FLAG(pspec->flags, G_PARAM_WRITABLE) && !IS_FLAG(pspec->flags, G_PARAM_CONSTRUCT_ONLY)){
             g_string_append_printf(source,
                 "def set_%s(val); set_property('%s', val); end\n",
                 prop_name, pspec->name);
@@ -506,6 +520,8 @@ Init_gobject()
     id_delete = rb_intern("delete");
     id_module_eval = rb_intern("module_eval");
 
+    rbgobj_id_children = rb_intern("__stored_children__");
+
     Init_gobject_gtype();
     Init_gobject_gvalue();
     Init_gobject_gvaluetypes();
