@@ -4,7 +4,7 @@
   rbgobject.h -
 
   $Author: mutoh $
-  $Date: 2005/06/16 13:27:33 $
+  $Date: 2005/11/06 06:41:14 $
 
   Copyright (C) 2003,2004  Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003  Masahiro Sakai
@@ -43,13 +43,30 @@ extern "C" {
     (rbgobj_define_class(gtype, name, module, mark, free, Qnil))
 
 #define G_RELATIVE(obj, rel) (rbgobj_add_relative(obj, rel))
+
+/* G_RELATIVE2 is useless now. Try G_CHILD_ADD/REMOVE first. */
 #define G_RELATIVE2(obj, rel, id, hash_key)\
  (rbgobj_add_relative_removable(obj, rel, id, hash_key))
 #define G_REMOVE_RELATIVE(obj, id, hash_key)\
  (rbgobj_remove_relative(obj, id, hash_key))
 
+extern ID rbgobj_id_children;
+#define G_CHILD_SET(self, id, child)  (rb_ivar_set(self, id, child))
+#define G_CHILD_UNSET(self, id)  (rb_ivar_set(self, id, Qnil))
+
+/* G_CHILD_ADD is same as G_RELATIVE, but the macro name is more obviously
+   to use than G_RELATIVE, and also support "remove" operation with the key
+   which is the object itself.
+*/
+#define G_CHILD_ADD(self, child) \
+    (rbgobj_add_relative_removable(self, Qnil, rbgobj_id_children, child))
+#define G_CHILD_REMOVE(self, child) \
+    (rbgobj_remove_relative(self, rbgobj_id_children, child))
+#define G_CHILD_REMOVE_ALL(self) \
+    (rbgobj_remove_relative_all(self, rbgobj_id_children))
+
 #define G_DEF_SIGNAL_FUNC(klass, sig_name, func)\
-(rbgobj_set_signal_func(klass, sig_name, func))
+ (rbgobj_set_signal_func(klass, sig_name, func))
 
 #define CLASS2CINFO(klass) (rbgobj_lookup_class(klass))
 #define GTYPE2CINFO(gtype) (rbgobj_lookup_class_by_gtype(gtype, Qnil))
@@ -102,6 +119,7 @@ extern void rbgobj_add_relative(VALUE obj, VALUE relative);
 extern void rbgobj_add_relative_removable(VALUE obj, VALUE relative,
                                           ID obj_ivar_id, VALUE hash_key);
 extern void rbgobj_remove_relative(VALUE obj, ID obj_ivar_id, VALUE hash_key);
+extern void rbgobj_remove_relative_all(VALUE obj, ID obj_ivar_id);
 
 extern GObject* rbgobj_gobject_new(GType type, VALUE params_hash);
 extern VALUE rbgobj_create_object(VALUE klass);
@@ -166,7 +184,7 @@ extern void rbgobj_boxed_not_copy_obj(GType gtype);
 extern void rbgobj_boxed_ref(VALUE obj, VALUE other);
 extern void rbgobj_boxed_unref(VALUE obj, VALUE other);
 
-/* rbgobj_enum.c */
+/* rbgobj_enums.c */
 extern void rbgobj_constant_remap(const char *original, const char *replacement);
 extern void rbgobj_add_constants(VALUE mod, GType type, const gchar *strip_prefix);
 extern VALUE rbgobj_make_enum(gint n, GType gtype);
