@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   helloworld.rb - Ruby/GTK first sample script.
 
   Copyright (c) 2002,2003 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: helloworld.rb,v 1.5 2003/04/01 16:21:19 mutoh Exp $
+  $Id: helloworld.rb,v 1.6 2005/03/22 17:41:28 silicio Exp $
 =end
 
 require 'gtk2'
