@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   to_drawable.rb - Gdk::Pixbuf(GDK methods) sample script.
 
-  Copyright (c) 2002,2003 Ruby-GNOME2 Project Team 
+  Copyright (c) 2002-2005 Ruby-GNOME2 Project Team 
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: to_drawable.rb,v 1.3 2003/02/01 16:46:23 mutoh Exp $
+  $Id: to_drawable.rb,v 1.5 2005/07/14 17:01:49 mutoh Exp $
 =end
 
 require 'gtk2'
@@ -18,25 +18,27 @@ end
 
 Gtk.init
 
-pixbuf =  Gdk::Pixbuf.new(filename)
+pixbuf = Gdk::Pixbuf.new(filename)
 
 w = Gtk::Window.new
+w.realize
 w.signal_connect('delete-event') do
   Gtk.main_quit
 end
 
 d = Gtk::DrawingArea.new
+gc = Gdk::GC.new(w.window)
 d.signal_connect('expose-event') do |w, e|
   unless e.count > 0
-    pixbuf.scale(w.allocation.width, w.allocation.height).
-      render_to_drawable(w.window, w.style.fg_gc(Gtk::STATE_NORMAL), 0, 0,
-			 0, 0, w.allocation.width, w.allocation.height)
+    width = w.allocation.width
+    height = w.allocation.height
+    pixbuf = pixbuf.scale(width, height)
+    d.window.draw_pixbuf(gc, pixbuf, 0, 0, 0, 0,
+			 width, height, Gdk::RGB::DITHER_NORMAL, 0, 0)
   end
-  GC.start
   true
 end
-d.show
-w.add d
-w.show
+w.add(d)
+w.show_all
 
 Gtk.main
