@@ -4,7 +4,7 @@
   rbgtktreeview.c -
 
   $Author: mutoh $
-  $Date: 2005/01/29 11:44:15 $
+  $Date: 2005/11/06 04:44:24 $
 
   Copyright (C) 2002-2005 Masao Mutoh
 ************************************************/
@@ -19,7 +19,8 @@
 #define RVAL2ITR(i) ((GtkTreeIter*)RVAL2BOXED(i, GTK_TYPE_TREE_ITER))
 #define RVAL2CELLRENDERER(c) (GTK_CELL_RENDERER(RVAL2GOBJ(c)))
 
-static ID id_column;
+static ID id_model;
+static ID id_selection;
 
 static VALUE
 treeview_initialize(argc, argv, self)
@@ -31,6 +32,7 @@ treeview_initialize(argc, argv, self)
     GtkWidget *widget;
 
     if (rb_scan_args(argc, argv, "01", &model) == 1) {
+        G_CHILD_SET(self, id_model, model);
         widget = gtk_tree_view_new_with_model(GTK_TREE_MODEL(RVAL2GOBJ(model)));
     }
     else {
@@ -45,7 +47,9 @@ static VALUE
 treeview_get_selection(self)
     VALUE self;
 {
-    return GOBJ2RVAL(gtk_tree_view_get_selection(_SELF(self)));
+    VALUE ret = GOBJ2RVAL(gtk_tree_view_get_selection(_SELF(self)));
+    G_CHILD_SET(self, id_selection, ret);
+    return ret;
 }
 
 static VALUE
@@ -60,7 +64,7 @@ static VALUE
 treeview_append_column(self, column)
     VALUE self, column;
 {
-    G_RELATIVE2(self, column, id_column, column);
+    G_CHILD_ADD(self, column);
     return INT2NUM(gtk_tree_view_append_column(_SELF(self), 
                                                TREEVIEW_COL(column)));
 }
@@ -69,7 +73,7 @@ static VALUE
 treeview_remove_column(self, column)
     VALUE self, column;
 {
-    G_REMOVE_RELATIVE(self, id_column, column);
+    G_CHILD_REMOVE(self, column);
     return INT2NUM(gtk_tree_view_remove_column(_SELF(self), 
                                                TREEVIEW_COL(column)));
 }  
@@ -103,7 +107,7 @@ treeview_insert_column(argc, argv, self)
                  &args[3]);        /*           attributes            */
 
     if (argc == 2) {
-        G_RELATIVE2(self, args[0], id_column, args[0]);
+        G_CHILD_ADD(self, args[0]);
         return INT2NUM(gtk_tree_view_insert_column(_SELF(self),
                                                    TREEVIEW_COL(args[0]),
                                                    NUM2INT(args[1])));
@@ -131,6 +135,10 @@ treeview_insert_column(argc, argv, self)
         GtkTreeViewColumn* column = gtk_tree_view_column_new();
 
         Check_Type(args[3], T_HASH);
+
+        G_CHILD_ADD(self, args[2]);
+        G_CHILD_ADD(self, args[3]);
+
         gtk_tree_view_column_set_title(column, RVAL2CSTR(args[1]));
         gtk_tree_view_column_pack_start(column, renderer, TRUE);
         
@@ -379,6 +387,21 @@ treeview_get_visible_rect(self)
     return BOXED2RVAL(&rect, GDK_TYPE_RECTANGLE);
 }
 
+#if GTK_CHECK_VERSION(2,8,0)
+static VALUE
+treeview_get_visible_range(self)
+    VALUE self;
+{
+    GtkTreePath* start_path;
+    GtkTreePath* end_path;
+
+    gboolean valid_paths = gtk_tree_view_get_visible_range(_SELF(self), &start_path, &end_path);
+
+    return valid_paths ? rb_assoc_new(TREEPATH2RVAL(start_path),
+                                      TREEPATH2RVAL(end_path)) : Qnil;
+}
+#endif
+
 static VALUE
 treeview_get_bin_window(self)
     VALUE self;
@@ -613,8 +636,8 @@ Init_gtk_treeview()
 {
     VALUE gTv = G_DEF_CLASS(GTK_TYPE_TREE_VIEW, "TreeView", mGtk);
 
-    id_column = rb_intern("__columns__");
-    rb_ivar_set(gTv, id_column, Qnil);
+    id_selection = rb_intern("selection");
+    id_model = rb_intern("model");
 
     rb_define_method(gTv, "initialize", treeview_initialize, -1);
     rb_define_method(gTv, "selection", treeview_get_selection, 0);
@@ -635,15 +658,20 @@ Init_gtk_treeview()
     rb_define_method(gTv, "collapse_all", treeview_collapse_all, 0);
     rb_define_method(gTv, "expand_row", treeview_expand_row, 2);
     rb_define_method(gTv, "collapse_row", treeview_collapse_row, 1);
-   #if GTK_CHECK_VERSION(2,2,0)
+#if GTK_CHECK_VERSION(2,2,0)
     rb_define_method(gTv, "expand_to_path", treeview_expand_to_path, 1);
-   #endif
+#endif
     rb_define_method(gTv, "map_expanded_rows", treeview_map_expanded_rows, 0);
     rb_define_method(gTv, "row_expanded?", treeview_row_expanded, 1);
     rb_define_method(gTv, "get_path_at_pos", treeview_get_path_at_pos, 2);
+    rb_define_alias(gTv, "get_path", "get_path_at_pos");
     rb_define_method(gTv, "get_cell_area", treeview_get_cell_area, 2);
     rb_define_method(gTv, "get_background_area", treeview_get_background_area, 2);
     rb_define_method(gTv, "visible_rect", treeview_get_visible_rect, 0);
+#if GTK_CHECK_VERSION(2,8,0)
+    rb_define_method(gTv, "visible_range", treeview_get_visible_range, 0);
+#endif
+
     rb_define_method(gTv, "bin_window", treeview_get_bin_window, 0);
     rb_define_method(gTv, "widget_to_tree_coords", treeview_widget_to_tree_coords, 2);
     rb_define_method(gTv, "tree_to_widget_coords", treeview_tree_to_widget_coords, 2);
@@ -654,6 +682,7 @@ Init_gtk_treeview()
     rb_define_method(gTv, "set_drag_dest_row", treeview_set_drag_dest_row, 2);
     rb_define_method(gTv, "drag_dest_row", treeview_get_drag_dest_row, 0);
     rb_define_method(gTv, "get_dest_row_at_pos", treeview_get_dest_row_at_pos, 2);
+    rb_define_alias(gTv, "get_dest_row", "get_dest_row_at_pos");
     rb_define_method(gTv, "create_row_drag_icon", treeview_create_row_drag_icon, 1);
     rb_define_method(gTv, "set_search_equal_func", treeview_set_search_equal_func, 0);
 #if GTK_CHECK_VERSION(2,2,0)
